@@ -1,6 +1,6 @@
 package CHI::Driver::File;
 BEGIN {
-  $CHI::Driver::File::VERSION = '0.52';
+  $CHI::Driver::File::VERSION = '0.53';
 }
 use Carp;
 use Cwd qw(realpath cwd);
@@ -138,8 +138,9 @@ sub get_keys {
     my ($self) = @_;
 
     my @filepaths;
-    my $wanted = sub { push( @filepaths, $_ ) if -f && /\.dat$/ };
-    my @keys = $self->_collect_keys_via_file_find( \@filepaths, $wanted );
+    my $re     = quotemeta( $self->file_extension );
+    my $wanted = sub { push( @filepaths, $_ ) if -f && /${re}$/ };
+    my @keys   = $self->_collect_keys_via_file_find( \@filepaths, $wanted );
     return @keys;
 }
 
@@ -153,8 +154,9 @@ sub _collect_keys_via_file_find {
 
     my @keys;
     my $key_start = length($namespace_dir) + 1 + $self->depth * 2;
+    my $subtract  = -1 * length( $self->file_extension );
     foreach my $filepath (@$filepaths) {
-        my $key = substr( $filepath, $key_start, -4 );
+        my $key = substr( $filepath, $key_start, $subtract );
         $key = $self->unescape_key( join( "", splitdir($key) ) );
         push( @keys, $key );
     }
@@ -248,7 +250,7 @@ directory structure
 
 =head1 VERSION
 
-version 0.52
+version 0.53
 
 =head1 SYNOPSIS
 
