@@ -1,6 +1,6 @@
 package CHI::Driver::Role::HasSubcaches;
 BEGIN {
-  $CHI::Driver::Role::HasSubcaches::VERSION = '0.52';
+  $CHI::Driver::Role::HasSubcaches::VERSION = '0.53';
 }
 use Moose::Role;
 use Hash::MoreUtils qw(slice_exists);
@@ -141,7 +141,7 @@ around 'get_multi_arrayref' => sub {
         my $l1_values = $l1_cache->get_multi_arrayref($keys);
         my @indices   = ( 0 .. scalar(@$keys) - 1 );
         my @primary_keys =
-          map { $keys->[$_] } grep { defined( $l1_values->[$_] ) } @indices;
+          map { $keys->[$_] } grep { !defined( $l1_values->[$_] ) } @indices;
         my $primary_values = $self->$orig( \@primary_keys );
         my $values         = [
             map {
