@@ -1,6 +1,6 @@
 package CHI::t::Driver::File;
 BEGIN {
-  $CHI::t::Driver::File::VERSION = '0.52';
+  $CHI::t::Driver::File::VERSION = '0.53';
 }
 use strict;
 use warnings;
@@ -24,7 +24,7 @@ sub new_cache_options {
 {
     package CHI::t::Driver::File::NoTempDriver;
 BEGIN {
-  $CHI::t::Driver::File::NoTempDriver::VERSION = '0.52';
+  $CHI::t::Driver::File::NoTempDriver::VERSION = '0.53';
 }
     use Moose;
     extends 'CHI::Driver::File';
@@ -39,7 +39,7 @@ BEGIN {
 {
     package CHI::t::Driver::File::BadTempDriver;
 BEGIN {
-  $CHI::t::Driver::File::BadTempDriver::VERSION = '0.52';
+  $CHI::t::Driver::File::BadTempDriver::VERSION = '0.53';
 }
     use Moose;
     extends 'CHI::Driver::File';
@@ -57,10 +57,10 @@ sub test_generate_temporary_filename : Tests {
     my $self = shift;
 
     $self->{cache} =
-      $self->new_cache( driver_class => 'CHI::t::Driver::File::NoTempDriver' );
+      $self->new_cache( driver => '+CHI::t::Driver::File::NoTempDriver' );
     $self->test_simple();
     $self->{cache} =
-      $self->new_cache( driver_class => 'CHI::t::Driver::File::BadTempDriver' );
+      $self->new_cache( driver => '+CHI::t::Driver::File::BadTempDriver' );
     throws_ok { $self->test_simple() } qr/error during cache set/;
 }
 
